#
# spec file for package python-djangorestframework
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-djangorestframework%{psuffix}
Version:        3.15.2
Release:        1.5
Summary:        A REST Framework for Django
License:        BSD-2-Clause
URL:            https://www.django-rest-framework.org/
Source:         https://github.com/encode/django-rest-framework/archive/%{version}.tar.gz#/djangorestframework-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 3.0
%if 0%{?suse_version} > 1500
Recommends:     python-Markdown
%endif
Recommends:     python-Pygments
Recommends:     python-requests
Suggests:       python-psycopg2
Provides:       python-django-rest-framework = %{version}
Obsoletes:      python-django-rest-framework < %{version}
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Django >= 3.0}
%if 0%{?suse_version} > 1500
BuildRequires:  %{python_module Markdown >= 3.3}
%endif
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module django-guardian >= 2.4.0}
BuildRequires:  %{python_module psycopg}
BuildRequires:  %{python_module pytest-django >= 4.1.0}
%endif
%python_subpackages

%description
Django REST framework is a library for building Web APIs. It is
modular and the architecture can be customized, based on Django's
class based views.

Web APIs built using REST framework are fully self-describing and web
browseable. It also supports a wide range of media types,
authentication and permission policies out of the box.

%prep
%autosetup -p1 -n django-rest-framework-%{version}

# Remove pytest params incompatible with older pytest on Leap
sed -i '/addopts/d' setup.cfg
# Remove pytest params breaking Tumbleweed
sed -i '/filterwarnings/d' setup.cfg

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
# Two tests failing due to incompatible output of Markdown 3.4 vs 3.3 pinned upstream
# https://github.com/encode/django-rest-framework/discussions/7980
# coreapi has been removed from Tumbleweed
%pytest -rs -vv -k 'not ((TestViewNamesAndDescriptions and test_markdown) or (TestDocumentationRenderer and test_shell_code_example_rendering) or test_coreapi)'
%endif

%if !%{with test}
%files %{python_files}
%doc README.md
%license LICENSE.md
%{python_sitelib}/rest_framework
%{python_sitelib}/djangorestframework-%{version}.dist-info
%endif

%changelog
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 3.15.2:
  * Fix potential XSS vulnerability in browsable API. #9435
  * Revert "Ensure CursorPagination respects nulls in the ordering
    field". #9381
  * Use warnings rather than logging a warning for DecimalField.
* Sat Apr 13 2024 John Vandenberg <jayvdb@gmail.com>
- Disable pytest filterwarnings which is breaking the test suite.
* Sun Apr  7 2024 Dirk Müller <dmueller@suse.com>
- update to 3.15.1:
  * Django 5.0 and Python 3.12 support
  * Use POST method instead of GET to perform logout in browsable API
  * Added jQuery 3.7.1 support & dropped previous version
  * Use str as default path converter
  * Partial serializer should not have required fields
  * Propagate 'default' from model field to serializer field.
  * Allow to override child.run_validation call in ListSerializer
  * Align SearchFilter behaviour to django.contrib.admin search
  * Class name added to unknown field error
  * Fix: Pagination response schemas.
  * Fix choices in ChoiceField to support IntEnum
  * Fix `SearchFilter` rendering search field with invalid value
  * Fix OpenAPI Schema yaml rendering for `timedelta`
  * Added Deprecation Warnings for CoreAPI
  * Removed usage of `field.choices` that triggered full table load
  * Permit mixed casing of string values for `BooleanField` validation
  * Fixes `BrowsableAPIRenderer` for usage with `ListSerializer`.
  * Change semantic of `OR` of two permission classes
  * Remove dependency on `pytz`
  * Make set_value a method within `Serializer`
  * Fix URLPathVersioning reverse fallback
  * Fix mapping for choice values
  * Refactor read function to use context manager for file handling
  * Fix: fallback on CursorPagination ordering if unset on the view
  * Replaced `OrderedDict` with `dict`
  * Implement `__eq__` for validators
  * Ensure CursorPagination respects nulls in the ordering field
  * Use ZoneInfo as primary source of timezone data
  * Add username search field for TokenAdmin (#8927)
  * Handle Nested Relation in SlugRelatedField when many=False
  * Bump version of jQuery to 3.6.4 & updated ref links
  * Support UniqueConstraint
  * Fix Respect `can_read_model` permission in DjangoModelPermissions
  * Add SimplePathRouter
  * Re-prefetch related objects after updating
  * Fix FilePathField required argument
  * Raise ImproperlyConfigured exception if `basename` is not unique
  * Use PrimaryKeyRelatedField pkfield in openapi
  * replace partition with split in BasicAuthentication
  * Fix BooleanField's allow_null behavior
  * Handle Django's ValidationErrors in ListField
  * Use autocomplete widget for user selection in Token admin
  * Make browsable API compatible with strong CSP
  * Avoid inline script execution for injecting CSRF token
  * Register Django urls
  * Implemented Verbose Name Translation for TokenProxy
  * Properly handle OverflowError in DurationField deserialization
  * Fix OpenAPI operation name plural appropriately
  * Represent SafeString as plain string on schema rendering
  * Fix 404 when page query parameter is empty string
  * Fixes instance check in ListSerializer.to_representation
  * FloatField will crash if the input is a number that is too big
  * Add missing DurationField to SimpleMetada label_lookup
  * Add support for Python 3.11
  * Make request consistently available in pagination classes
  * Possibility to remove trailing zeros on DecimalFields representation
  * Add a method for getting serializer field name (OpenAPI)
  * Add `__eq__` method for `OperandHolder` class
  * Avoid importing `django.test` package when not testing
  * Preserve exception messages for wrapped Django exceptions
  * Include `examples` and `format` to OpenAPI schema of
    CursorPagination (https://github.>
  * Fix infinite recursion with deepcopy on Request
  * Refactor: Replace try/except with contextlib.suppress()
  * Minor fix to SerializeMethodField docstring
  * Minor refactor: Unnecessary use of list() function
  * Unnecessary list comprehension
  * Use correct class to indicate present deprecation
* Tue Mar 12 2024 Max Lin <mlin@suse.com>
- ggDo not use python-Markdown in Leap 15
  * Leap 15 does not have python 3.11 build of python-Markdown
* Tue Jan 30 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- Drop core{api,schema} from BuildRequires/Recommends, they are no
  longer developed, and will be removed.
- Switch to psycopg (so version 3).
* Fri Jun 23 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Thu Jan 26 2023 John Vandenberg <jayvdb@gmail.com>
- Skip two tests failing upstream with latest Markdown.
* Sat Sep 24 2022 Markéta Machová <mmachova@suse.com>
- Update to 3.14.0
  * Django 2.2 is no longer supported. [#8662]
  * Django 4.1 compatibility. [#8591]
  * Don't evaluate DateTimeField.default_timezone when a custom
    timezone is set. [#8531]
  * Make relative URLs clickable in Browseable API. [#8464]
  * Make ReturnDict support dict union operators on Python 3.9 and
    later. [#8302]
- Drop merged patch 8530-update-tests-new-Pygments.patch
* Thu Aug 25 2022 John Vandenberg <jayvdb@gmail.com>
- Skip two tests, TestPosgresFieldsMapping.test_array_field and
  TestViewNamesAndDescriptions.test_markdown
- Add README.md to package
- Be more precise about files included under site-packages
* Mon Jun 20 2022 Matej Cepl <mcepl@suse.com>
- Add 8530-update-tests-new-Pygments.patch to allow working with
  the current Pygments (gh#encode/django-rest-framework#8160).
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Sat Dec 25 2021 John Vandenberg <jayvdb@gmail.com>
- Re-activate tests on Leap 15.2
- Update to v3.13.1
  * Revert schema naming changes with function based `@api_view`
  * Fix CursorPagination parameter schema type
- from v3.13
  * Django 4.0 support
  * Fields arguments are now keyword-only
* Thu Sep  9 2021 Matej Cepl <mcepl@suse.com>
- Update to 3.12.4:
  - Properly handle ATOMIC_REQUESTS when multiple database
    configurations are used. [#7739]
  - Bypass COUNT query when LimitOffsetPagination is configured
    but pagination params are not included on the request.
    [#6098]
  - Respect allow_null=True on DecimalField. [#7718]
  - Allow title cased "Yes"/"No" values with BooleanField.
    [#7739]
  - Add PageNumberPagination.get_page_number() method for
    overriding behavior. [#7652]
  - Fixed rendering of timedelta values in OpenAPI schemas, when
    present as default, min, or max fields. [#7641]
  - Render JSONFields with indentation in browsable API forms.
    [#6243]
  - Remove unnecessary database query in admin Token views.
    [#7852]
  - Raise validation errors when bools are passed to
    PrimaryKeyRelatedField fields, instead of casting to ints.
    [#7597]
  - Don't include model properties as automatically generated
    ordering fields with OrderingFilter. [#7609]
  - Use deque instead of list for tracking throttling .history.
    [#7849]
  - Fix issue if rest_framework.authtoken.models is imported, but
    rest_framework.authtoken is not in INSTALLED_APPS. [#7571]
  - Ignore subclasses of BrowsableAPIRenderer in OpenAPI schema.
    [#7497]
  - Narrower exception catching in serilizer fields, to ensure
    that any errors in broken get_queryset() methods are not
    masked. [#7480]
  - Add TokenProxy migration. [#7557]
  - Add --file option to generateschema command. [#7130]
  - Support tags for OpenAPI schema generation. See the schema
    docs. [#7184]
  - Support customising the operation ID for schema generation.
    See the schema docs. [#7190]
  - Support OpenAPI components for schema generation. See the
    schema docs. [#7124]
  - The following methods on AutoSchema become public API:
    get_path_parameters, get_pagination_parameters,
    get_filter_parameters, get_request_body, get_responses,
    get_serializer, get_paginator, map_serializer, map_field,
    map_choice_field, map_field_validators, allows_filters. See
    the schema docs
  - Add support for Django 3.1's database-agnositic JSONField.
    [#7467]
  - SearchFilter now supports nested search on JSONField and
    HStoreField model fields. [#7121]
  - SearchFilter now supports searching on annotate() fields.
    [#6240]
  - The authtoken model no longer exposes the pk in the admin
    URL. [#7341]
  - Add __repr__ for Request instances. [#7239]
  - UTF-8 decoding with Latin-1 fallback for basic auth
    credentials. [#7193]
  - CharField treats surrogate characters as a validation
    failure. [#7026]
  - Don't include callables as default values in schemas. [#7105]
  - Improve ListField schema output to include all available
    child information. [#7137]
  - Allow default=False to be included for BooleanField schema
    outputs. [#7165]
  - Include "type" information in ChoiceField schema outputs.
    [#7161]
  - Include "type": "object" on schema objects. [#7169]
  - Don't include component in schema output for DELETE requests.
    [#7229]
  - Fix schema types for DecimalField. [#7254]
  - Fix schema generation for ObtainAuthToken view. [#7211]
  - Support passing context=... to view .get_serializer()
    methods. [#7298]
  - Pass custom code to PermissionDenied if permission class has
    one set. [#7306]
  - Include "example" in schema pagination output. [#7275]
  - Default status code of 201 on schema output for POST
    requests. [#7206]
  - Use camelCase for operation IDs in schema output. [#7208]
  - Warn if duplicate operation IDs exist in schema output.
    [#7207]
  - Improve handling of decimal type when mapping ChoiceField to
    a schema output. [#7264]
  - Disable YAML aliases for OpenAPI schema outputs. [#7131]
  - Fix action URL names for APIs included under a namespaced
    URL. [#7287]
  - Update jQuery version from 3.4 to 3.5. [#7313]
  - Fix UniqueTogether handling when serializer fields use
    source=.... [#7143]
  - HTTP HEAD requests now set self.action correctly on a ViewSet
    instance. [#7223]
  - Return a valid OpenAPI schema for the case where no API
    schema paths exist. [#7125]
  - Include tests in package distribution. [#7145]
  - Allow type checkers to support annotations like
    ModelSerializer[Author]. [#7385]
  - Don't include invalid charset=None portion in the request
    Content-Type header when using APIClient. [#7400]
  - Fix \Z/\z tokens in OpenAPI regexs. [#7389]
  - Fix PrimaryKeyRelatedField and HyperlinkedRelatedField when
    source field is actually a property. [#7142]
  - Token.generate_key is now a class method. [#7502]
  - @action warns if method is wrapped in a decorator that does
    not preserve information using @functools.wraps. [#7098]
- Skip TestNaiveDayLightSavingTimeTimeZoneDateTimeField.test_invalid_inputs
  (gh#encode/django-rest-framework#8159)
- Skip TestViewNamesAndDescriptions.test_markdown
  (gh#encode/django-rest-framework#8160).
* Fri Feb 12 2021 Markéta Machová <mmachova@suse.com>
- Update to 3.11.2
  * Security: Drop urlize_quoted_links template tag in favour of
    Django's built-in urlize. Removes a XSS vulnerability for some
    kinds of content in the browsable API. (boo#1177205, CVE-2020-25626)
* Thu Sep  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.11.1
  * update Django for APIs book to 3.0 edition
  * decode base64 credentials as utf8; adjust tests
  * Remove compat urls for Django < 2.0
* Mon Jan  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.11.0:
  * various minor updates
  * django 3.x compatibility
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.10.3:
  * Drop python2 support
  * Various bugfixes
* Mon May  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.9.3:
  * This is the last Django REST Framework release that will support Python 2.
  * Adjusted the compat check for django-guardian to allow the last guardian
    version (v1.4.9) compatible with Python 2. #6613
* Wed Mar  6 2019 John Vandenberg <jayvdb@gmail.com>
- Fix broken suggestion python-psycopg2
- Increased optional dependency django-guardian >= 1.5.0
- Update to v3.9.2
  * Routers: invalidate `_urls` cache on `register()`
  * Deferred schema renderer creation to avoid requiring pyyaml
  * Added 'request_forms' block to base.html
  * Fixed SchemaView to reset renderer on exception
  * Update Django Guardian dependency
  * Ensured support for Django 2.2
  * Made templates compatible with session-based CSRF
  * Adjusted field `validators` to accept non-list iterables
  * Added SearchFilter.get_search_fields() hook
  * Fix DeprecationWarning when accessing collections.abc classes via collections
  * Allowed Q objects in limit_choices_to introspection
  * Added lazy evaluation to composed permissions
  * Add negation ~ operator to permissions composition
  * Avoided calling distinct on annotated fields in SearchFilter
  * Introduced `RemovedInDRF…Warning` classes to simplify deprecations
* Fri Mar  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to multibuild to avoid buildcycle with django-filter
* Sun Feb 24 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Add Recommends and Suggests for optional runtime dependencies
- Update to v3.9.1
  * Resolve XSS issue in browsable API
  * Resolve issues with composable permissions
  * Respect `limit_choices_to` on foreign keys
* Sun Nov 11 2018 Thomas Bechtold <tbechtold@suse.com>
- update to version 3.9.0:
  * (fix) link to disqus article on cursor pagination (#6020)
  * Add kloudless as a new premium sponsor (#6241)
  * Add building with drf book (#6102)
  * Documentation fix for django-admin commands (#6232)
  * Remove unnecessary models.py file (#6142)
  * Add Oct 18 release date
  * Clean up unnecessary if statement (#6163)
  * codecov: enable status for patch/changes, comment: diff (#6080)
  * Add "optionals not required" build (#6047)
  * Fix typo in docs (#6212)
  * Update JWT docs. (#6138)
  * Fix dist build (#6139)
  * Add Django 2.1 to classifiers (#6099)
  * Correct schema parsing for JSONField (#5878)
  * Ensure that html forms (multipart form data) respect optional fields (#5927)
  * Render markdown readme on PyPI (#6004)
  * requirements-testing: update pytest and pytest-django (#5972)
  * tox/pytest: move posargs, use -ra (#6039)
  * Fixed instance being overwritten in pk-only optimization try/except block (#5747)
  * Update to Django 2.0 Routing Syntax (#6049)
  * requirements-optionals: use psycopg2-binary (#5969)
  * [DOCS] python print syntax
  * Added djangorestframework-datatables to third-party packages (#5931)
  * Fix upload parser test (#6044)
  * Allow nullable BooleanField in Django 2.1 (#6183)
  * Simplify job matrix on Travis (#6174)
  * tests: fix skipping with TestPosgresFieldsMapping (#5965)
  * Add docs link to Caching API Guide. (#6012)
  * Allow hashing of ErrorDetail to fix #5919 (#5932)
  * tests: fix usage of transaction.non_atomic_requests (#6043)
  * Add (beginning of) 3.9 release announcement.
  * Move guardian imports out of compat (#6054)
  * Update codecov.yml
  * Removed exclude_from_schema per deprecation policy.
  * Bring docs license text up to date
  * Update 3.9 announcement
  * Add `OpenAPIRenderer` and `generate_schema` management command. (#6229)
  * updated tox and travis for django 2.1 alpha1
  * Improvements to ViewSet extra actions (#5605)
  * Updated list_route() and detail_route() deprecations.
  * Update the http signature auth library ref link (#5997)
  * Update release notes and add deprecation note for Django Guardian backend.
  * Fix schemas for extra actions (#5992)
  * permissions: Allow permissions to be composed (#5753)
  * Add minimal codecov comment (#6077)
  * tests/test_permissions.py: do not add view perm for dj21 (#6055)
  * pytest: use --strict (#5966)
  * Drop Django 1.10 support (#5657)
  * Update version for v3.9.0
  * Render descriptions (from help_text) using safe (#5869)
  * fix e.indexOf is not a function error (#5982)
  * Add NotImplementedError to coverage exclusion (#6057)
  * tests: fix test_write_only_fields not being executed (#5971)
  * Change ISO 8601 date format to exclude year/month (#5936)
  * Remove unnecessary use of compat shim six.binary_type (#6189)
  * Fix spelling error (#6198)
  * Update .gitignore
  * update testing.md - fixes related to RequestsClient (#5959)
  * Handle models without .objects manager in ModelSerializer. (#6111)
  * Add missing comma (#5978)
  * Update LICENSE.md
  * Prefer https:// for URLs when available throughout project (#6208)
  * Deprecate DjangoObjectPermissionsFilter (#6075)
  * Prefer io.BytesIO over six; available on all supported Pythons (#6168)
  * Documentation: Correct the signature for HyperlinkedRelatedField.get_object()
  * Fix exceptions.md (#6003)
  * Rename base_name => basename for consistency's sake (#5990)
  * Fix docs typos (#6195)
  * Add drf-renderer-xlsx package. (#6147)
  * Update codecov.yml (#6224)
  * runtests.py: clean up PYTEST_ARGS (#6040)
  * Add Load Impact to premium sponsors (#6176)
  * Use [tool:pytest] header in setup.cfg (#6045)
  * Fix grammar mistake in html-and-forms.md (#6070)
  * Include coverage for tests (#5970)
  * Fix Load Impact URL
  * Add release note for #6073
  * Added pagination section to the quickstart page (#5987)
  * Add "Community" section to docs, minor cleanup (#5993)
  * Delete config
  * requirements-optionals.txt: bump psycopg2 to 2.7.4 (#5967)
  * Delete .editorconfig
  * Fixed AttributeError from items filter when value is None (#5981)
  * tests: remove some dead code, use `assert 0` for never called methods (#5973)
  * Mention Django 2.1 compat where missing (#6158)
  * Remove dot character from "pagination_class" (#6137)
  * Admin renderer urls (#5988)
  * Fix deprecation warnings in tests (#6076)
  * Update incorrect PyPI URL to register an account
  * Fix CSRF cookie check failure when using session auth with django 1.11.6+ (#6113)
  * Small grammar correction in quickstart. (#6121)
  * Docs: Match original argument names (#5889)
  * Adjusted client JWT example (#5944)
  * Feature/action docs sections (#6060)
  * Higher res. load impact logo
  * Removed input value from deault_error_message (#5881)
  * [docs] Remove leftover from former python 3.2/3.3 support (#5947)
  * Only catch TypeError/ValueError for object lookups (#6028)
  * Weakened to PendingDeprecationWarning for `base_name`
  * get_error_detail: use error_dict/error_list (#5785)
  * Ensure docs sidebar can scroll to bottom. (#5949)
  * Add announcement section for Extra Actions in Browsable API
  * Add REST APIs with Django book (#6033)
  * Fix url for group_names action example (#6036)
  * Update tutorial to Django 2.0 routing syntax (#5963) (#5964)
  * Add Kloudless logo
  * Add Cadre as a premium sponsor (#5941)
  * Fix validate_my_field signature
  * tests: update pytest/pytest-django (#6042)
  * Update all pypi.python.org URLs to pypi.org (#5942)
  * Improve ModelSerializer.create() error message. (#6112)
  * Update link to django-rest-marshmallow docs (#5925)
  * Add Load Impact to README
  * Add release notes to dd19a44583e30bdb325da23583f2a934399155e1
  * Move pytest config to setup.cfg (#5979)
  * Added 3.8 release + updated monthly report link
  * Fix typo error, Link to Field (#6078)
  * min_value/max_value support in DurationField (#5643)
  * Prohibit null characters in CharField by default (#6073)
  * Adding release notes
  * Fix a typo in the 3.8 announcement (#5940)
  * Update tox to use Django  v2.1b1 (#6037)
  * Release notes to 5174a26ec9d50c7b1e934ee2613de4ae2e2c
  * Upgrade Auklet to premium (#6244)
  * Test using Django 2.1 final release (#6109)
  * Update documenting-your-api.md (#5991)
  * remove references to DOAC in docs (#5977)
  * Add Python 3.7 support (#6141)
  * Problem: autoescape not getting passed to urlize_quoted_links filter (#6191)
  * Add spacing around kloudless logo
  * Added import statement on filtering docs
  * Fix Python 3.8 compatibility (#6154)
  * Add OpenAPIRenderer by default, and add schema docs. (#6233)
  * Fix action support for ViewSet suffixes (#6081)
* Wed Aug  8 2018 jengelh@inai.de
- Trim rhetorics and ensure neutrality of description.
* Wed Aug  1 2018 tchvatal@suse.com
- Version update to 3.8.2
  * Support django 1.11 as minimal
  * Add support for django 2.1
* Sun Dec 24 2017 matwey.kornilov@gmail.com
- djangorestframework 3.7 requires Django 1.10+ (see Release Notes)
  In particluar, it uses
    from django.urls import reverse
  that not existed prior 1.10
* Fri Dec 15 2017 sbrabec@suse.com
- Update to version 3.7.3:
  * improvements to schema generation and the interactive API
    documentation.
  * Django 2.0 suport.
  * Python 3.7 support.
  * For more see
    http://www.django-rest-framework.org/topics/release-notes/
* Mon May 15 2017 matwey.kornilov@gmail.com
- update to version 3.6.3:
  * Raise 404 if a URL lookup results in ValidationError. (#5126)
  * Honor http_method_names on class based view, when generating
    API schemas. (#5085)
  * Allow overridden get_limit in LimitOffsetPagination to return
    all records. (#4437)
  * Fix partial update for the ListSerializer. (#4222)
  * Render JSONField control correctly in browsable API. (#4999,
    [#5042])
  * Raise validation errors for invalid datetime in given timezone.
    (#4987)
  * Support restricting doc & schema shortcuts to a subset of urls.
    (#4979)
  * Resolve SchemaGenerator error with paginators that have no
    page_size attribute. (#5086, #3692)
  * Resolve HyperlinkedRelatedField exception on string with %%20
    instead of space. (#4748, #5078)
  * Customizable schema generator classes. (#5082)
  * Update existing vary headers in response instead of overwriting
    them. (#5047)
  * Support passing .as_view() to view instance. (#5053)
  * Use correct exception handler when settings overridden on a
    view. (#5055, #5054)
  * Update Boolean field to support 'yes' and 'no' values. (#5038)
  * Fix unique validator for ChoiceField. (#5004, #5026, #5028)
  * JavaScript cleanups in API Docs. (#5001)
  * Include URL path regexs in API schemas where valid. (#5014)
  * Correctly set scheme in coreapi TokenAuthentication. (#5000,
    [#4994])
  * HEAD requests on ViewSets should not return 405. (#4705, #4973,
    [#4864])
  * Support usage of 'source' in extra_kwargs. (#4688)
  * Fix invalid content type for schema.js (#4968)
  * Fix DjangoFilterBackend inheritance issues. (#5089, #5117)
- changes from 3.6.2
  * Support for Safari & IE in API docs. (#4959, #4961)
  * Add missing mark_safe in API docs template tags. (#4952, #4953)
  * Add missing glyicon fonts. (#4950, #4951)
  * Fix One-to-one fields in API docs. (#4955, #4956)
  * Test clean ups. (#4949)
- changes from 3.6.1
  * Ensure markdown dependancy is optional. (#4947)
- changes from 3.5.x:
  * Built-in interactive API documentation support.
  * A new JavaScript client library.
* Mon Feb  6 2017 sbrabec@suse.com
- Update to version 3.5.3:
  * Use fields or exclude on serializer classes.
  * Microsecond precision when returning time or datetime.
  * Relational choices no longer displayed in OPTIONS requests.
  * Improved schema generation.
  * Requests test client.
  * Core API client.
  * Live tests.
  * RAML support.
  * Validation codes.
  * Client upload & download support.
  * Deprecations.
  * Other improvements.
  * For details see:
    http://www.django-rest-framework.org/topics/3.4-announcement/
    http://www.django-rest-framework.org/topics/3.5-announcement/
* Fri Apr  1 2016 matwey.kornilov@gmail.com
- Update to version 3.3.3:
  * Remove version string from templates. Thanks to @blag for the report and
    fixes. (#3878, #3913, #3912)
  * Fixes vertical html layout for BooleanField. Thanks to Mikalai Radchuk for
    the fix. (#3910)
  * Silenced deprecation warnings on Django 1.8. Thanks to Simon Charette for
    the fix. (#3903)
  * Internationalization for authtoken. Thanks to Michael Nacharov for the fix.
    (#3887, #3968)
  * Fix Token model as abstract when the authtoken application isn't declared.
  * Thanks to Adam Thomas for the report. (#3860, #3858)
  * Improve Markdown version compatibility. Thanks to Michael J. Schultz for the
    fix. (#3604, #3842)
  * QueryParameterVersioning does not use DEFAULT_VERSION setting. Thanks to
  * Brad Montgomery for the fix. (#3833)
  * Add an explicit on_delete on the models. Thanks to Mads Jensen for the fix.
    (#3832)
  * Fix DateField.to_representation to work with Python 2 unicode. Thanks to
  * Mikalai Radchuk for the fix. (#3819)
  * Fixed TimeField not handling string times. Thanks to Areski Belaid for the
    fix. (#3809)
  * Avoid updates of Meta.extra_kwargs. Thanks to Kevin Massey for the report
    and fix. (#3805, #3804)
  * Fix nested validation error being rendered incorrectly. Thanks to Craig de
    Stigter for the fix. (#3801)
  * Document how to avoid CSRF and missing button issues with
    django-crispy-forms. Thanks to Emmanuelle Delescolle, José Padilla and Luis
  * San Pablo for the report, analysis and fix. (#3787, #3636, #3637)
  * Improve Rest Framework Settings file setup time. Thanks to Miles Hutson for
    the report and Mads Jensen for the fix. (#3786, #3815)
  * Improve authtoken compatibility with Django 1.9. Thanks to S. Andrew
    Sheppard for the fix. (#3785)
  * Fix Min/MaxValueValidator transfer from a model's DecimalField. Thanks to
    Kevin Brown for the fix. (#3774)
  * Improve HTML title in the Browsable API. Thanks to Mike Lissner for the
    report and fix. (#3769)
  * Fix AutoFilterSet to inherit from default_filter_set. Thanks to Tom Linford
    for the fix. (#3753)
  * Fix transifex config to handle the new Chinese language codes. Thanks to
    @nypisces for the report and fix. (#3739)
  * DateTimeField does not handle empty values correctly. Thanks to Mick Parker for the report and fix. (#3731, #3726)
  * Raise error when setting a removed rest_framework setting. Thanks to Luis
    San Pablo for the fix. (#3715)
  * Add missing csrf_token in AdminRenderer post form. Thanks to Piotr
    Śniegowski for the fix. (#3703)
  * Refactored _get_reverse_relationships() to use correct to_field. Thanks to
    Benjamin Phillips for the fix. (#3696)
  * Document the use of get_queryset for RelatedField. Thanks to Ryan Hiebert
    for the fix. (#3605)
  * Fix empty pk detection in HyperlinkRelatedField.get_url. Thanks to @jslang
    for the fix (#3962)
* Fri Jul 24 2015 matwey.kornilov@gmail.com
- Update to version 3.1.3:
  * A super-smart cursor pagination scheme.
  * An improved pagination API, supporting header or in-body pagination styles.
  * Pagination controls rendering in the browsable API.
  * Better support for API versioning.
  * Built-in internationalization support.
  * Support for Django 1.8's HStoreField and ArrayField.
* Mon Jul 13 2015 toddrme2178@gmail.com
- Fix building on SLES 11
* Sun Jan 11 2015 p.drouand@gmail.com
- Update to version 3.0.3
  * Fix MinValueValidator on models.DateField. (#2369)
  * Fix serializer missing context when pagination is used. (#2355)
  * Namespaced router URLs are now supported by the DefaultRouter. (#2351)
  * required=False allows omission of value for output. (#2342)
  * Use textarea input for models.TextField. (#2340)
  * Use custom ListSerializer for pagination if required. (#2331, #2327)
  * Better behavior with null and '' for blank HTML fields. (#2330)
  * Ensure fields in exclude are model fields. (#2319)
  * Fix IntegerField and max_length argument incompatibility. (#2317)
  * Fix the YAML encoder for 3.0 serializers. (#2315, #2283)
  * Fix the behavior of empty HTML fields. (#2311, #1101)
  * Fix Metaclass attribute depth ignoring fields attribute. (#2287)
  * Fix format_suffix_patterns to work with Django's i18n_patterns. (#2278)
  * Ability to customize router URLs for custom actions, using url_path. (#2010)
  * Don't install Django REST Framework as egg. (#2386)
- Provide and obsolete redundant python-django-rest-framework
* Fri Nov 29 2013 david.bahid@emc.com
- update to 2.3.12
  * removed patch to removed unicode support to enable SLES11
    not needed for SLES11 SP3 with python 2.6.8 and SP2 fails
    even if updated patch is applied (and SP3 fails with patch).
  * Move to 2.3 base release for the restframework
    introduces the ViewSet and Router classes
    simplified generic view classes
    easier serializers
    more flexible filtering
    simpler URL lookups
    file upload parser
    decimal field
    add reverse relationships to the fields option on a ModelSerializer class
    get_related_field and get_nested_field method signatures have now changed
    mechanics of names and descriptions used in the browseable API are
    generated has been modified and cleaned up
  * see http://django-rest-framework.org/topics/2.3-announcement for more details
- Remove django-rest-framework-no-unicode-literals.diff; older python
  versions are unsupported anyway
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sat Feb 16 2013 jfunk@funktronics.ca
- Update to 2.2.0
  * Python 3 support.
  * Added a post_save() hook to the generic views.
  * Allow serializers to handle dicts as well as objects.
  * Deprecate ManyRelatedField() syntax in favor of RelatedField(many=True)
  * Deprecate null=True on relations in favor of required=False.
  * Deprecate blank=True on CharFields, just use required=False.
  * Deprecate optional obj argument in permissions checks in favor of
    has_object_permission.
  * Deprecate implicit hyperlinked relations behavior.
  * Bugfix: Fix broken DjangoModelPermissions.
  * Bugfix: Allow serializer output to be cached.
  * Bugfix: Fix styling on browsable API login.
  * Bugfix: Fix issue with deserializing empty to-many relations.
  * Bugfix: Ensure model field validation is still applied for ModelSerializer
    subclasses with an custom .restore_object() method.
- Disable unicode_literals feature on older Python
* Mon Jan 21 2013 jfunk@funktronics.ca
- Update to 2.1.16:
  * Deprecate django.utils.simplejson in favor of Python 2.6's built-in json
    module.
  * Bugfix: auto_now, auto_now_add and other editable=False fields now default
    to read-only.
  * Bugfix: PK fields now only default to read-only if they are an AutoField
    or if editable=False.
  * Bugfix: Validation errors instead of exceptions when serializers receive
    incorrect types.
  * Bugfix: Validation errors instead of exceptions when related fields
    receive incorrect types.
  * Bugfix: Handle ObjectDoesNotExist exception when serializing null reverse
    one-to-one
  * Note: Prior to 2.1.16, The Decimals would render in JSON using floating
    point if simplejson was installed, but otherwise render using string
    notation. Now that use of simplejson has been deprecated, Decimals will
    consistently render using string notation. See #582 for more details.
- 2.1.15
  * Added PATCH support.
  * Added RetrieveUpdateAPIView.
  * Remove unused internal save_m2m flag on ModelSerializer.save().
  * Tweak behavior of hyperlinked fields with an explicit format suffix.
  * Relation changes are now persisted in .save() instead of in
    .restore_object().
  * Bugfix: Fix issue with FileField raising exception instead of validation
    error when files=None.
  * Bugfix: Partial updates should not set default values if field is not
    included.
* Tue Jan  1 2013 jfunk@funktronics.ca
- Update to 2.1.14:
  * Bugfix: ModelSerializers now include reverse FK fields on creation.
  * Bugfix: Model fields with blank=True are now required=False by default.
  * Bugfix: Nested serializers now support nullable relationships.
  * Note: From 2.1.14 onwards, relational fields move out of the fields.py
    module and into the new relations.py module, in order to seperate them
    from regular data type fields, such as CharField and IntegerField. This
    change will not affect user code, so long as it's following the
    recommended import style of from rest_framework import serializers and
    refering to fields using the style serializers.PrimaryKeyRelatedField.
- 2.1.13
  * Support configurable STATICFILES_STORAGE storage.
  * Bugfix: Related fields now respect the required flag, and may be
    required=False.
- 2.1.12
  * Bugfix: Fix bug that could occur using ChoiceField.
  * Bugfix: Fix exception in browseable API on DELETE.
  * Bugfix: Fix issue where pk was was being set to a string if set by URL
    kwarg.
- 2.1.11
  * Bugfix: Fix issue with M2M fields in browseable API.
- 2.1.10
  * Bugfix: Ensure read-only fields don't have model validation applied.
  * Bugfix: Fix hyperlinked fields in paginated results.
- 2.1.9
  * Bugfix: Fix broken nested serialization.
  * Bugfix: Fix Meta.fields only working as tuple not as list.
  * Bugfix: Edge case if unnecessarily specifying required=False on read only
    field.
- 2.1.8
  * Fix for creating nullable Foreign Keys with '' as well as None.
  * Added null=<bool> related field option.
- 2.1.7
  * Serializers now properly support nullable Foreign Keys.
  * Serializer validation now includes model field validation, such as
    uniqueness constraints.
  * Support 'true' and 'false' string values for BooleanField.
  * Added pickle support for serialized data.
  * Support source='dotted.notation' style for nested serializers.
  * Make Request.user settable.
  * Bugfix: Fix RegexField to work with BrowsableAPIRenderer
- 2.1.6
  * Bugfix: Unfix DjangoModelPermissions. (I am a doofus.)
- 2.1.5
  * Bugfix: Fix DjangoModelPermissions.
- 2.1.4
  * Support for partial updates with serializers.
  * Added RegexField.
  * Added SerializerMethodField.
  * Serializer performance improvements.
  * Added obtain_token_view to get tokens when using TokenAuthentication.
  * Bugfix: Django 1.5 configurable user support for TokenAuthentication.
* Wed Nov 21 2012 jfunk@funktronics.ca
- Update to 2.1.3:
  * Added FileField and ImageField. For use with MultiPartParser.
  * Added URLField and SlugField.
  * Support for read_only_fields on ModelSerializer classes.
  * Support for clients overriding the pagination page sizes. Use the
    PAGINATE_BY_PARAM setting or set the paginate_by_param attribute on a
    generic view.
  * 201 Responses now return a 'Location' header.
  * Bugfix: Serializer fields now respect max_length.
* Tue Nov 13 2012 jfunk@funktronics.ca
- Update to 2.1.2:
  * Filtering support.
  * Bugfix: Support creation of objects with reverse M2M relations.
- 2.1.1
  * Support use of HTML exception templates. Eg. 403.html
  * Hyperlinked fields take optional slug_field, slug_url_kwarg and
    pk_url_kwarg arguments.
  * Bugfix: Deal with optional trailing slashs properly when generating
    breadcrumbs.
  * Bugfix: Make textareas same width as other fields in browsable API.
  * Private API change: .get_serializer now uses same instance and data
    ordering as serializer initialization.
- 2.1.0
  * Serializer instance and data keyword args have their position swapped.
  * queryset argument is now optional on writable model fields.
  * Hyperlinked related fields optionally take slug_field and slug_url_kwarg
    arguments.
  * Support Django's cache framework.
  * Minor field improvements. (Don't stringify dicts, more robust many-pk
    fields.)
  * Bugfix: Support choice field in Browseable API.
  * Bugfix: Related fields with read_only=True do not require a queryset
    argument.
- 2.0.2
  * Fix issues with pk related fields in the browsable API.
- 2.0.1
  * Add support for relational fields in the browsable API.
  * Added SlugRelatedField and ManySlugRelatedField.
  * If PUT creates an instance return '201 Created', instead of '200 OK'.
- 2.0.0
  * Fix all of the things. (Well, almost.)
  * For more information please see the 2.0 announcement.
- 0.4.0
  * Supports Django 1.5.
  * Fixes issues with 'HEAD' method.
  * Allow views to specify template used by TemplateRenderer
  * More consistent error responses
  * Some serializer fixes
  * Fix internet explorer ajax behaviour
  * Minor xml and yaml fixes
  * Improve setup (eg use staticfiles, not the defunct ADMIN_MEDIA_PREFIX)
  * Sensible absolute URL generation, not using hacky set_script_prefix
- 0.3.3
  * Added DjangoModelPermissions class to support django.contrib.auth style
    permissions.
  * Use staticfiles for css files.
  * Easier to override. Won't conflict with customised admin styles (eg
    grappelli)
  * Templates are now nicely namespaced.
  * Allows easier overriding.
  * Drop implied 'pk' filter if last arg in urlconf is unnamed.
  * Too magical. Explict is better than implicit.
  * Saner template variable autoescaping.
  * Tider setup.py
  * Updated for URLObject 2.0
  * Bug with PerUserThrottling when user contains unicode chars.
- 0.3.2
  * Fix 403 for POST and PUT from the UI with UserLoggedInAuthentication
    (#115)
  * serialize_model method in serializer.py may cause wrong value (#73)
  * Fix Error when clicking OPTIONS button (#146)
  * And many other fixes
  * Remove short status codes
  * Zen of Python: "There should be one-- and preferably only one --obvious
    way to do it."
  * get_name, get_description become methods on the view - makes them
    overridable.
  * Improved model mixin API - Hooks for build_query, get_instance_data,
    get_model, get_queryset, get_ordering
- Run tests
- Ran spec-cleaner on spec
* Thu Jan 12 2012 jfunk@funktronics.ca
- Initial release
